@@ -7,12 +7,12 @@ from .tasks import create_thumbnail
 
 class AsyncThumbnailMixin(object):
     """
-    All model which have ImageField to be thumbnailed inheret from this class. 
+    All model which have ImageField to be thumbnailed inheret from this class.
     """
     image_field_name = 'picture'
 
     def call_upload_task(self):
-        for name, options in settings.OPTIONS_DICT.iteritems():
+        for name, options in settings.OPTIONS_DICT.items():
             opt = copy(options)
             geometry = opt.pop('geometry')
             create_thumbnail.delay(getattr(self, self.image_field_name), geometry, **opt)
