@@ -8,7 +8,7 @@ def create_thumbnail(image_file, geometry_string, **options):
     # Note that thumbnail options must be same for a type of thumbnail.
     # Otherwise, different thumbnails are created.
     source = ImageFile(image_file)
-    for key, value in default.backend.default_options.iteritems():
+    for key, value in default.backend.default_options.items():
             options.setdefault(key, value)
     name = default.backend._get_thumbnail_filename(source, geometry_string, options)
     thumbnail = ImageFile(name, default.storage)
