@@ -5,10 +5,10 @@ from copy import copy
 
 def get_thumbnail_options_from_dict(dictt):
     ret= {}
-    for name, options in dictt.iteritems():
+    for name, options in dictt.items():
         opt = copy(options)
         geometry = opt.pop('geometry')
-        new_options = ['%s=%s' % (k, v) for k, v in opt.iteritems()]
+        new_options = ['%s=%s' % (k, v) for k, v in opt.items()]
         new_options.insert(0, geometry)
         ret[name] = ' '.join(new_options)
     return ret
\ No newline at end of file
